package WebGUI::i18n::Spanish::AuthWebGUI;
use utf8;
our $I18N = {
  1 => {
    'lastUpdated' => '1291129638',
    'message' => 'Opciones de Autenticación WebGUI'
  },
  10 => {
    'lastUpdated' => '1291129647',
    'message' => 'Contraseña Anterior'
  },
  11 => {
    'lastUpdated' => '1291129660',
    'message' => 'Nueva Contraseña'
  },
  12 => {
    'lastUpdated' => '1291129677',
    'message' => 'No puede volver a utilizar la contraseña anterior como nueva contraseña.'
  },
  13 => {
    'lastUpdated' => '1207704777',
    'message' => '&iquest;Permitir recuperar la contrase&ntilde;a?'
  },
  14 => {
    'lastUpdated' => '1291129695',
    'message' => 'Longitud Mínima para Contraseña'
  },
  15 => {
    'lastUpdated' => '1291129732',
    'message' => 'Longitud Mínima para Contraseña'
  },
  '15 help' => {
    'lastUpdated' => '1233703955',
    'message' => 'La longitud mínima de las contraseñas que los usuarios están obligados a utilizar, en caracteres.'
  },
  16 => {
    'lastUpdated' => '1291129749',
    'message' => 'Vigencia de la Contraseña'
  },
  '16 help' => {
    'lastUpdated' => '1234630698',
    'message' => 'El vencimiento de una clave de acceso que define cuánto tiempo es válido esa clave. Después del vencimiento, el usuario deberá ingresar una nueva clave.'
  },
  17 => {
    'lastUpdated' => '1291129763',
    'message' => 'Contraseña Actualizada'
  },
  18 => {
    'lastUpdated' => '1291129813',
    'message' => '¿Permitir el cambio de contraseñas?'
  },
  '18 help' => {
    'lastUpdated' => '1234630829',
    'message' => '¿Les estará permitido a los usuarios modificar sus claves de acceso? Tenga en cuenta que conjuntamente con vencimientos dispuestos, esta configuración puede causar mucho trabajo para el administrador.'
  },
  19 => {
    'lastUpdated' => '1291129801',
    'message' => '¿Permitir el cambio de nombre de usuario?'
  },
  '19 help' => {
    'lastUpdated' => '1234630851',
    'message' => '¿Los usuarios podrán modificar su nombre de usuario después de crear su cuenta?'
  },
  2 => {
    'lastUpdated' => '1232555450',
    'message' => 'Escriba su contraseña nuevamente'
  },
  20 => {
    'lastUpdated' => '1291129829',
    'message' => '¿Permitir el cambio de contraseña?'
  },
  21 => {
    'lastUpdated' => '1291129840',
    'message' => '¿Permitir el cambio de nombre de usuario?'
  },
  22 => {
    'lastUpdated' => '1207705220',
    'message' => 'No hay campos para actualizar'
  },
  3 => {
    'lastUpdated' => '1291129853',
    'message' => 'Las contraseñas no coinciden, por favor intente nuevamente'
  },
  4 => {
    'lastUpdated' => '1291129865',
    'message' => 'No puede dejar la contraseña en blanco.'
  },
  5 => {
    'lastUpdated' => '1291129888',
    'message' => 'La contraseña no puede ser la palabra "password".'
  },
  6 => {
    'lastUpdated' => '1291129900',
    'message' => '¿Permitir la recuperación de contraseñas?'
  },
  7 => {
    'lastUpdated' => '1291129968',
    'message' => "La contrase\x{f1}a es muy corta \x{2014} su longitud debe ser al menos "
  },
  8 => {
    'lastUpdated' => '1291129994',
    'message' => 'Su contraseña ha vencido.'
  },
  9 => {
    'lastUpdated' => '1291130026',
    'message' => '¿Expirar la contraseña al crear el usuario?'
  },
  '9 help' => {
    'lastUpdated' => '1234630941',
    'message' => 'Esto obligará al usuario a cambiar su contraseña de inmediato una vez que se crea la cuenta.'
  },
  'Password Recovery Email Template' => {
    'lastUpdated' => '1289571578',
    'message' => 'Plantilla Correo de Recuperación de Clave'
  },
  'account activation template' => {
    'lastUpdated' => '1253635773',
    'message' => 'Plantilla para Correo de Activación de Cuenta'
  },
  'account activation template help' => {
    'lastUpdated' => '1253635797',
    'message' => 'Seleccione la Plantilla a emplear para construir el mensaje de correo de activación de cuenta que se envía a los usuarios nuevos.'
  },
  'account activation template title' => {
    'lastUpdated' => '1253635819',
    'message' => 'Plantilla para Mensaje de Correo de Activación de Cuenta WebGUI'
  },
  'account deactivate account template title' => {
    'lastUpdated' => '1270050731',
    'message' => 'Plantilla para Desactivar Cuenta con Autenticación WebGUI'
  },
  'account template' => {
    'lastUpdated' => '1207706348',
    'message' => 'Plantilla del registro'
  },
  'account template help' => {
    'lastUpdated' => '1234630976',
    'message' => 'Seleccione una plantilla para la pantalla que muestra la cuenta de usuario para el usuario.'
  },
  'account.form.password' => {
    'lastUpdated' => '1207699920',
    'message' => 'Contrase&ntilde;a por defecto para el campo del formulario.'
  },
  'account.form.password.label' => {
    'lastUpdated' => '1207699843',
    'message' => 'Texto por defecto para la contrase&ntilde;a en el campo del formulario.'
  },
  'account.form.passwordConfirm' => {
    'lastUpdated' => '1207699770',
    'message' => 'Confirmar contrase&ntilde;a por defecto en el campo del formulario.'
  },
  'account.form.passwordConfirm.label' => {
    'lastUpdated' => '1207699646',
    'message' => 'Texto por defecto para confirmar la contrase&ntilde;a en el campo del formulario.'
  },
  'account.form.username' => {
    'lastUpdated' => '1207699570',
    'message' => 'Usuario por defecto para el campo del formulario.'
  },
  'account.form.username.label' => {
    'lastUpdated' => '1207699983',
    'message' => 'Texto por defecto para el usuario en el campo del formulario.'
  },
  'account.message' => {
    'lastUpdated' => '1207700045',
    'message' => 'Alg&uacute;n mensaje retornado por el sistema.&nbsp; Usualmente lo muestra despu&eacute;s de guardar el formulario.'
  },
  'account.nofields' => {
    'lastUpdated' => '1207700348',
    'message' => 'Muestra por defecto en el caso de que no haya elementos para mostrar en el formulario.'
  },
  'account.noform' => {
    'lastUpdated' => '1207700699',
    'message' => 'Indica si el formulario de la cuenta a mostrar tiene alg&uacute;n campo visible.'
  },
  'activationUrl' => {
    'lastUpdated' => '1253635834',
    'message' => 'El URL para activar la cuenta recién creada.'
  },
  'anon reg template title' => {
    'lastUpdated' => '1207706406',
    'message' => 'Plantilla de atenticaci&oacute;n WebGui de registro an&oacute;nimo'
  },
  'anonymousRegistration.isAllowed' => {
    'lastUpdated' => '1207704111',
    'message' => 'Bandera que indica si registro an&oacute;nimo est&aacute; permitido.'
  },
  'captcha failure' => {
    'lastUpdated' => '1207704199',
    'message' => 'Usted necesita digitar los seis caracteres que usted ve en la imagen para probar que usted es humano.'
  },
  'captcha label' => {
    'lastUpdated' => '1207704266',
    'message' => 'Ingrese los caracteres de la imagen'
  },
  'check email for validation' => {
    'lastUpdated' => '1207704298',
    'message' => 'Por favor verifique su correo para activar su cuenta.'
  },
  'create account template' => {
    'lastUpdated' => '1207706437',
    'message' => 'Crear plantilla de registro'
  },
  'create account template help' => {
    'lastUpdated' => '1234631004',
    'message' => 'Seleccione una plantilla para mostrar la pantalla en la cual el usuario creará una cuenta para este sitio.'
  },
  'create.form.hidden' => {
    'lastUpdated' => '1207706701',
    'message' => 'Campos ocultos del formulario requeridos para la presentaci&oacute;n del formulario'
  },
  'create.form.oldPassword' => {
    'lastUpdated' => '1207705461',
    'message' => 'Contrase&ntilde;a anterior por defecto en el campo del formulario.'
  },
  'create.form.oldPassword.label' => {
    'lastUpdated' => '1207705500',
    'message' => 'Texto por defecto para la contrase&ntilde;a anterior en el campo del formulario.'
  },
  'create.form.password' => {
    'lastUpdated' => '1207704357',
    'message' => 'Contrase&ntilde;a por defecto para el campo del formulario.'
  },
  'create.form.password.label' => {
    'lastUpdated' => '1207704452',
    'message' => 'Texto por defecto para la contrase&ntilde;a en el campo del formulario.'
  },
  'create.form.passwordConfirm' => {
    'lastUpdated' => '1207705561',
    'message' => 'Confirmar contrase&ntilde;a por defecto en el campo del formulario.'
  },
  'create.form.passwordConfirm.label' => {
    'lastUpdated' => '1207705607',
    'message' => 'Texto por defecto para confirmar contrase&ntilde;a en el campo del formulario.'
  },
  'create.form.username' => {
    'lastUpdated' => '1207705643',
    'message' => 'Usuario por defecto en el campo del formulario'
  },
  'create.form.username.label' => {
    'lastUpdated' => '1207705746',
    'message' => 'Texto por defecto para el usuario en el campo del formulario'
  },
  'create.message' => {
    'lastUpdated' => '1207705799',
    'message' => 'Alg&uacute;n mensaje retornado por el sistema.&nbsp; Usualmente mostrado despu&eacute;s de guardar el formulario'
  },
  'createAccount.label' => {
    'lastUpdated' => '1207705900',
    'message' => 'Etiqueta por defecto para el v&iacute;nculo del registro an&oacute;nimo'
  },
  'createAccount.url' => {
    'lastUpdated' => '1207706784',
    'message' => 'URL de la pagina de registro an&oacute;nimo'
  },
  'deactivate account template' => {
    'lastUpdated' => '1270050745',
    'message' => 'Plantilla para Desactivar Cuenta'
  },
  'deactivate account template help' => {
    'lastUpdated' => '1270050766',
    'message' => 'Indique la Plantilla a utilizar para presentar el formulario que permite Desactivar una Cuenta de usuario.'
  },
  'deactivate account template title' => {
    'lastUpdated' => '1207712019',
    'message' => 'WebGui Autenticaci&oacute;n, plantilla de desacctivaci&oacute;n de cuenta'
  },
  'display account template title' => {
    'lastUpdated' => '1207712259',
    'message' => 'WebGui Autenticaci&oacute;n, plantilla de detalles de la cuenta de usuario'
  },
  'displayTitle' => {
    'lastUpdated' => '1207705944',
    'message' => 'T&iacute;tulo de la p&aacute;gina por defecto.'
  },
  'email address validation email body' => {
    'lastUpdated' => '1207712332',
    'message' => 'Bienvenido a nuestro sitio, Por favor haga click en el siguiente enlace para activar su cuenta'
  },
  'email address validation email subject' => {
    'lastUpdated' => '1207712354',
    'message' => 'Activaci&oacute;n de la cuenta'
  },
  'email password recovery end message' => {
    'lastUpdated' => '1207712400',
    'message' => 'Ingrese la nueva contrase&ntilde;a para la cuenta'
  },
  'email recover password finish message' => {
    'lastUpdated' => '1226516213',
    'message' => 'Se ha enviado un mensaje de correo electr&oacute;nico con las instrucciones que deber&aacute; seguir para recuperar su contrase&ntilde;a.'
  },
  'email recover password finish message1' => {
    'lastUpdated' => '1207704756',
    'message' => 'Un correo ha sido enviado a'
  },
  'email recover password finish message2' => {
    'lastUpdated' => '1207704799',
    'message' => 'Con instrucciones para reestablecer su contrase&ntilde;a.'
  },
  'email recover password start message' => {
    'lastUpdated' => '1207705071',
    'message' => 'Ingrese a continuaci&oacute;n su direcci&oacute;n de correo electr&oacute;nico o su registro para iniciar el proceso de recuperac&oacute;n de la contrase&ntilde;a.'
  },
  'email validation confirmed' => {
    'lastUpdated' => '1234631033',
    'message' => 'Gracias por activar su cuenta. Ahora podrá ingresar con su nombre de usuario y contraseña.'
  },
  'error password nonWordCharacters' => {
    'lastUpdated' => '1207712517',
    'message' => 'La contrase&ntilde;a debe contener por lo menos %s caracteres no imprimibles (tales como \'!\', \'@\' o \'$\')'
  },
  'error password requiredDigits' => {
    'lastUpdated' => '1207704572',
    'message' => 'Contrase&ntilde;a deber&iacute;a tener al menos %s caracteres num&eacute;ricos.'
  },
  'error password requiredMixedCase' => {
    'lastUpdated' => '1207704709',
    'message' => 'Contrase&ntilde;a deber&iacute;a tener al menos %s caracteres en may&uacute;scula y al menos un caracter en min&uacute;scula.'
  },
  'error passwordRecoveryType no profile fields required' => {
    'lastUpdated' => '1207712729',
    'message' => 'No se puede habilitar la recuperaci&oacute;n de contrase&ntilde;as por medio de los campos del perfil, No hay campos en el perfil requeridos para la recuperci&oacute;n de contrase&ntilde;a.'
  },
  'expired password template' => {
    'lastUpdated' => '1216239931',
    'message' => 'Plantilla Expiraci&oacute;n de Contrase&ntilde;a'
  },
  'expired password template help' => {
    'lastUpdated' => '1234631063',
    'message' => 'Seleccione una plantilla para mostrar la pantalla en la cual un usuario ingresa una nueva clave después que la vieja ha caducado.'
  },
  'expired template title' => {
    'lastUpdated' => '1216239969',
    'message' => 'Autenticaci&ograve;n WebGui Plantilla Expiraci&oacute;n de Contrase&ntilde;a'
  },
  'expired.form.footer' => {
    'lastUpdated' => '1207712883',
    'message' => 'Los elementos requeridos del formulario que van despu&eacute;s del formulario de la p&aacute;gina de la expiraci&oacute;n de la contrase&ntilde;a'
  },
  'expired.form.header' => {
    'lastUpdated' => '1207712935',
    'message' => 'Los elementos requeridos del formulario que van en la tapa de la p&aacute;gina de la expiraci&oacute;n de la contrase&ntilde;a.'
  },
  'expired.form.hidden' => {
    'lastUpdated' => '1207713157',
    'message' => 'Campos ocultos del formulario requeridos para el formulario de presentaci&oacute;n'
  },
  'expired.form.password' => {
    'lastUpdated' => '1207713211',
    'message' => 'Campo de contrase&ntilde;a del formulario por defecto'
  },
  'expired.form.password.label' => {
    'lastUpdated' => '1207713362',
    'message' => 'Campo de texto por defecto para la contrase&ntilde;a en el formulario'
  },
  'expired.form.passwordConfirm' => {
    'lastUpdated' => '1207714197',
    'message' => 'Campo del formulario por defecto para la confirmaci&oacute;n de la contrase&ntilde;a'
  },
  'expired.form.passwordConfirm.label' => {
    'lastUpdated' => '1207713853',
    'message' => 'Texto por defecto para el campo de confirmaci&oacute;n de contrase&ntilde;a en el formulario'
  },
  'expired.form.submit' => {
    'lastUpdated' => '1207714269',
    'message' => 'El boton&nbsp; por defecto para el formulario de expiraci&oacute;n de la contrase&ntilde;a'
  },
  'expired.message' => {
    'lastUpdated' => '1207714334',
    'message' => 'Todos los mensajes devueltos por el sistema, Usualmente se muestran desp&uacute;es que el formulario se ha enviado'
  },
  'login template' => {
    'lastUpdated' => '1216240011',
    'message' => 'Plantilla de Ingreso'
  },
  'login template help' => {
    'lastUpdated' => '1234631112',
    'message' => 'Seleccione una plantilla para mostrar la pantalla donde el usuario puede ingresar al sitio. Esto es diferente de los Macros que también pueden mostrar formularios de ingreso al usuario.'
  },
  'login template title' => {
    'lastUpdated' => '1207714371',
    'message' => 'Plantilla de Autenticaci&oacute;n de WebGui'
  },
  'login.form.email' => {
    'lastUpdated' => '1207714406',
    'message' => 'Campo de correo por defecto del formulario.'
  },
  'login.form.email.label' => {
    'lastUpdated' => '1207713892',
    'message' => 'Texto por defecto para el campo de email en el formulario'
  },
  'login.label' => {
    'lastUpdated' => '1207705239',
    'message' => 'Etiqueta de texto por defecto para el v&iacute;nculo de p&aacute;gina de acceso.'
  },
  'login.message' => {
    'lastUpdated' => '1207705299',
    'message' => 'Alg&uacute;n mensaje retornado por el sistema.&nbsp; Usualmente lo muestra despu&eacute;s de guardar el formulario.'
  },
  'login.url' => {
    'lastUpdated' => '1207705327',
    'message' => 'Direcci&oacute;n para la p&aacute;gina de acceso.'
  },
  'new password help' => {
    'lastUpdated' => '1207705351',
    'message' => 'Ingrese su nueva contrase&ntilde;a aqu&iacute;'
  },
  'new password label' => {
    'lastUpdated' => '1207705372',
    'message' => 'Nueva contrase&ntilde;a'
  },
  'new password verify' => {
    'lastUpdated' => '1207705394',
    'message' => 'Verificar Nueva contrase&ntilde;a.'
  },
  'new password verify help' => {
    'lastUpdated' => '1207713440',
    'message' => 'Ingrese su contrase&ntilde;a de nuevo para verificaci&oacute;n'
  },
  'newUser_password' => {
    'lastUpdated' => '1253635851',
    'message' => 'La clave para la cuenta recién creada.'
  },
  'newUser_username' => {
    'lastUpdated' => '1253635864',
    'message' => 'El nombre de usuario para la cuenta recién creada.'
  },
  'no email address' => {
    'lastUpdated' => '1234630748',
    'message' => 'No hay un correo electrónico registrado para esta cuenta. No es posible recuperar la clave a través de correo electrónico.'
  },
  'no registration hack' => {
    'lastUpdated' => '1215807857',
    'message' => 'completa el registo an&oacute;nimo llamado directamente desde la URL por createAccountSave.'
  },
  'password recovery disabled' => {
    'lastUpdated' => '1215808047',
    'message' => 'Tu cuenta ha sido desabilitada. No puedes recuperar tu contrase&ntilde;a hasta que no sea activada.'
  },
  'password recovery email hoverHelp' => {
    'lastUpdated' => '1207723579',
    'message' => 'Ingrese aquí su dirección de correo electrónico'
  },
  'password recovery email label' => {
    'lastUpdated' => '1207713475',
    'message' => 'Direcci&oacute;n de correo'
  },
  'password recovery email template help' => {
    'lastUpdated' => '1289571607',
    'message' => 'Seleccione la plantilla a emplear para la construcción de los mensajes de correo enviados durante el proceso de recuperación de clave.'
  },
  'password recovery login hoverHelp' => {
    'lastUpdated' => '1207723536',
    'message' => 'Introduce aquí tu nombre de usuario'
  },
  'password recovery login label' => {
    'lastUpdated' => '1207713541',
    'message' => 'Nombre de usuario'
  },
  'password recovery multiple results' => {
    'lastUpdated' => '1207723482',
    'message' => 'Lo sentimos, la recuperación de la contraseña de esta cuenta no se puede realizar. Póngase en contacto con el administrador.'
  },
  'password recovery no results' => {
    'lastUpdated' => '1207723380',
    'message' => 'No se ha encontrado usuarios que coincidan con los datos sobre el perfil. Por favor, inténtalo de nuevo.'
  },
  'password recovery no username' => {
    'lastUpdated' => '1207723293',
    'message' => 'La contraseña de recuperación requiere un nombre de usuario.'
  },
  'password recovery template' => {
    'lastUpdated' => '1207723172',
    'message' => 'Plantilla de recuperación de la contraseña'
  },
  'password recovery template help' => {
    'lastUpdated' => '1234631141',
    'message' => 'Seleccione la plantalla a desplegar donde el usuario puede recuperar una contraseña perdida.'
  },
  'recover password banner' => {
    'lastUpdated' => '1207722800',
    'message' => 'Recuperación de la contraseña'
  },
  'recover password email text1' => {
    'lastUpdated' => '1207722933',
    'message' => 'Hemos recibido su solicitud para cambiar la contraseña por'
  },
  'recover password email text2' => {
    'lastUpdated' => '1207723215',
    'message' => 'Por favor, utilice el siguiente enlace para visitar el sitio y cambiar su contraseña.'
  },
  'recover password email text3' => {
    'lastUpdated' => '1207723122',
    'message' => 'Si no ha solicitado su contraseña para ser recuperada, por favor, póngase en contacto con el administrador del sistema.'
  },
  'recover password not found' => {
    'lastUpdated' => '1207723063',
    'message' => 'No tenemos registro de un usuario que coincida con la información que nos ha dado'
  },
  'recover.form.footer' => {
    'lastUpdated' => '1207723004',
    'message' => 'Los elementos del formulario que van después de la página de recuperación de la contraseña.'
  },
  'recover.form.header' => {
    'lastUpdated' => '1207722859',
    'message' => 'Los elementos del formulario que van en la parte superior de la página de recuperación de contraseña.'
  },
  'recover.form.hidden' => {
    'lastUpdated' => '1215808076',
    'message' => 'Esconder los campos requeridos en el formulario para el envio.'
  },
  'recover.form.submit' => {
    'lastUpdated' => '1207711328',
    'message' => 'El valor por defecto para el bot&oacute;n enviar&nbsp; en el formulario de recuperaci&oacute;n de contrase&ntilde;a'
  },
  'recover.message' => {
    'lastUpdated' => '1207711548',
    'message' => 'Alg&uacute;n mensaje retornado por el sistema.&nbsp; Usualmente lo muestra despu&eacute;s de guardar el formulario.'
  },
  'recoverFormProfile' => {
    'lastUpdated' => '1207711692',
    'message' => 'Ciclo sobre los campos del profile necesarios para la recuperaci&oacute;n de la contrase&ntilde;a.'
  },
  'recoverFormProfile formElement' => {
    'lastUpdated' => '1207711619',
    'message' => 'Un elemento del formulario para el campo del profile.'
  },
  'recoverFormProfile id' => {
    'lastUpdated' => '1207711486',
    'message' => 'El ID en el campo del profile.'
  },
  'recoverFormProfile label' => {
    'lastUpdated' => '1207711359',
    'message' => 'La etiqueta para el campo del profile.'
  },
  'recoverFormUsername' => {
    'lastUpdated' => '1207706404',
    'message' => 'Usuario en el campo del formulario para la recuperaci&oacute;n de la contrase&ntilde;a.'
  },
  'recoverFormUsernameLabel' => {
    'lastUpdated' => '1207711162',
    'message' => 'Etiqueta para el nombre de usuario en el campo del formulario para recuperar la contrase&ntilde;a.'
  },
  'recoverPassword.isAllowed' => {
    'lastUpdated' => '1207706294',
    'message' => 'Bandera indicando si recuperaci&oacute;n de la contrase&ntilde;a est&aacute; habilitado'
  },
  'recoverPassword.label' => {
    'lastUpdated' => '1207706173',
    'message' => 'Etiqueta por defecto para el v&iacute;nculo de recuperaci&oacute;n de la contrase&ntilde;a'
  },
  'recoverPassword.url' => {
    'lastUpdated' => '1207711117',
    'message' => 'Direcci&oacute;n para la p&aacute;gina de recuperaci&oacute;n de contrase&ntilde;a.'
  },
  'recoverPasswordUrl' => {
    'lastUpdated' => '1289571620',
    'message' => 'El URL que el usuario debe visitar para recuperar su clave.'
  },
  'recovery email template title' => {
    'lastUpdated' => '1289571648',
    'message' => 'Plantilla para Correo de Recuperación de Clave bajo Autenticación WebGUI'
  },
  'recovery template title' => {
    'lastUpdated' => '1207711084',
    'message' => 'Template de autenticaci&oacute;n en WebGUI para recuperar contrase&ntilde;a '
  },
  'require username for password recovery' => {
    'lastUpdated' => '1207706345',
    'message' => 'Requiere usuario para recuperaci&oacute;n de la contrase&ntilde;a?'
  },
  'setting passwordRecoveryType email' => {
    'lastUpdated' => '1207711009',
    'message' => 'Direcci&oacute;n de correo electr&oacute;nico'
  },
  'setting passwordRecoveryType none' => {
    'lastUpdated' => '1207710990',
    'message' => 'No'
  },
  'setting passwordRecoveryType profile' => {
    'lastUpdated' => '1207706497',
    'message' => 'Campo en el profile'
  },
  'setting webguiNonWordCharacters' => {
    'lastUpdated' => '1207710978',
    'message' => 'N&uacute;mero de caracteres sin palabras requeridos en la contrase&ntilde;a'
  },
  'setting webguiNonWordCharacters help' => {
    'lastUpdated' => '1234631184',
    'message' => 'La cantidad de cararcteres no-palabras, tales como puntuación, que se requieren para integrar la contraseña del usuario.'
  },
  'setting webguiRequiredDigits' => {
    'lastUpdated' => '1207710847',
    'message' => 'N&uacute;mero de d&iacute;gitos requeridos en la contrase&ntilde;a'
  },
  'setting webguiRequiredDigits help' => {
    'lastUpdated' => '1234631207',
    'message' => '¿Cuántos dítigos/numeros se requieren en la contraseña del usuario?'
  },
  'setting webguiRequiredMixedCase' => {
    'lastUpdated' => '1207710815',
    'message' => 'N&uacute;mero de caracteres en may&uacute;scula requeridos en la contrase&ntilde;a'
  },
  'setting webguiRequiredMixedCase help' => {
    'lastUpdated' => '1234631245',
    'message' => 'Esta configuración exige que el usuario incluya letras en mayúsculas en su contraseña. No les exigirá tener letras en minúscula en sus contraseñas.'
  },
  'subtitle' => {
    'lastUpdated' => '1233704592',
    'message' => 'Instrucciones especiales para el formulario. No puede ser definido en todos los tipos de plantillas de recuperación de contraseña.'
  },
  'title' => {
    'lastUpdated' => '1207706130',
    'message' => 'T&iacute;tulo de la p&aacute;gina por defecto.'
  },
  'token already used' => {
    'lastUpdated' => '1226516268',
    'message' => 'La ficha (token) de recuperaci&oacute;n de contrase&ntilde;a suministrada ya ha sido utilizada.'
  },
  'topicName' => {
    'lastUpdated' => '1291130063',
    'message' => 'Autenticación WebGUI'
  },
  'use captcha' => {
    'lastUpdated' => '1291130076',
    'message' => '¿Usar CAPTCHA?'
  },
  'use captcha help' => {
    'lastUpdated' => '1234631288',
    'message' => 'Si coloca "Si" aquí, el usuario deberá ingresar el texto de un captcha para crear una cuenta nueva.'
  },
  'use email as username description' => {
    'lastUpdated' => '1253635908',
    'message' => 'Si se indica \'si\', la pantalla de registro no mostrará un campo para el nombre de usuario sino que la dirección de correo ingresada será utilizada como nombre para la nueva cuenta de usuario.'
  },
  'use email as username label' => {
    'lastUpdated' => '1253635925',
    'message' => '¿Usar Dirección de Correo como nombre de usuario?'
  },
  'validate email' => {
    'lastUpdated' => '1207706055',
    'message' => 'Validar direcciones de correo electr&oacute;nico?'
  },
  'validate email help' => {
    'lastUpdated' => '1234631418',
    'message' => 'Debe WebGUI enviar un correo electrónica a esta persona, independientemente del mensaje de bienvendia, que incluya un enlace a su cuenta? La cuenta del usuario no se activará hasta que ese enlace sea visitado y cuentas sin validar expirarán después de un tiempo configurable. Este período de tiempo se indica en un flujo de trabajo.'
  },
  'webguiPasswordRecovery hoverHelp' => {
    'lastUpdated' => '1253636020',
    'message' => 'Seleccione "campo del perfil" para permitir que los usuarios que conocen a una determinada combinación de los campos de su perfil para recuperar sus contraseñas. Para que esto tenga efecto, por lo menos un campo del perfil debe tener su "requerido para la recuperación de la contraseña?". Es muy recomendable para recoger varios campos, como la utilización de un único campo suele ser muy fácil de romper, recuerda que todo aquel que descubre la totalidad de los campos para un usuario puede restablecer la contraseña de dicho usuario. Seleccione "Correo" para permitir a los usuarios disponer de un correo electrónico enviado a ellas con un vínculo que les permitirá restablecer su contraseña.'
  },
  'webguiPasswordRecoveryRequireUsername hoverHelp' => {
    'lastUpdated' => '1253636025',
    'message' => 'Select "Si" si usted quiere que los usuarios también tengan que ingresar el nombre de usuario para recuperar la contraseña. De lo contrario, ellos serían capaces de reestablecer su contraseña y ingresar ellos mismos sabiendo solamente que otros campos del profile están habilitados para recuperar la contraseña, incluso si ellos han olvidado su nombre de usuario.'
  },
  'welcome message template' => {
    'lastUpdated' => '1253635939',
    'message' => 'Plantilla para Mensaje de Bienvenida'
  },
  'welcome message template help' => {
    'lastUpdated' => '1253635964',
    'message' => 'Seleccione la Plantilla a emplear para construir el mensaje de bienvenida que se envía a los usuarios nuevos.'
  },
  'welcome message template title' => {
    'lastUpdated' => '1253635993',
    'message' => 'Plantilla para Mensaje de Bienvenida (Autenticación WebGUI)'
  },
  'welcomeMessage' => {
    'lastUpdated' => '1253636012',
    'message' => 'El mensaje de bienvenida tal como se define en la configuración de autenticación.'
  }
}
;

1;
